#
# spec file for package nagstamon
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Lars Vogdt
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nagstamon
Version:        2.0.1
Release:        lp152.3.2
Summary:        Nagios status monitor for the desktop
License:        GPL-2.0
Group:          System/Monitoring
Url:            http://nagstamon.ifw-dresden.de/
Source:         Nagstamon-%{version}.tar.bz2
Source1:        %{name}.desktop
BuildRequires:  python3-devel
#
# Fedora dependencies
#
%if 0%{?fedora_version}
BuildRequires:  desktop-file-utils
BuildRequires:  python3-qt5
Requires:       python3
Requires:       python3-SecretStorage
Requires:       python3-beautifulsoup4
Requires:       python3-crypto
Requires:       python3-psutil
Requires:       python3-qt5
Requires:       python3-requests
Requires:       qt5-qtsvg
%endif
#
# openSUSE dependencies
#
%if 0%{?suse_version}
BuildRequires:  libqt5-qtmultimedia-devel
BuildRequires:  python-SecretStorage
BuildRequires:  python3-beautifulsoup4
BuildRequires:  python3-psutil
BuildRequires:  python3-pycrypto
BuildRequires:  python3-qt5
BuildRequires:  python3-qt5
BuildRequires:  python3-requests
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       python-SecretStorage
Requires:       python3-beautifulsoup4
Requires:       python3-psutil
Requires:       python3-pycrypto
Requires:       python3-qt5
Requires:       python3-requests
Recommends:     gnome-terminal
Recommends:     rdesktop
Recommends:     sox
Recommends:     tightvnc
%py_requires
%endif
#
# Mandriva dependencies
#
%if 0%{?mandriva_version}
BuildRequires:  desktop-file-utils
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%{!?python3_sitelib: %global python3_sitelib %(python3 -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}

%description
Nagstamon is a Nagios status monitor which takes place in systray or on desktop
(GNOME, KDE, Windows) as floating statusbar to inform you in realtime about the
status of your Nagios and derivatives monitored network. It allows to connect
to multiple Nagios, Icinga, Opsview, Op5, Check_MK/Multisite and Centreon
servers.

%prep
%setup -q -n Nagstamon
# currently we use our own desktop file
test -f Nagstamon/resources/nagstamon.desktop && rm Nagstamon/resources/nagstamon.desktop
install -Dm644 %{SOURCE1} Nagstamon/resources/nagstamon.desktop

%build
python3 setup.py build

%install
python3 setup.py install \
				--single-version-externally-managed \
				-O1 \
 				--root=%{buildroot} \
				--install-lib=%{python3_sitelib} \
				--prefix=%{_prefix}
mv %{buildroot}/%{_bindir}/nagstamon.py %{buildroot}/%{_bindir}/nagstamon
if [ -d %buildroot/Nagstamon ]; then
    mkdir -p %{buildroot}/%{python3_sitelib}
	my Nagstamon %{buildroot}/%{python3_sitelib}/
fi
# desktop stuff
chmod -x %{buildroot}%{_datadir}/pixmaps/nagstamon.svg
chmod -x %{buildroot}%{python3_sitelib}/Nagstamon/resources/*.svg
for file in $(grep -wlr bin/env %{buildroot}%{python3_sitelib}/Nagstamon/*); do
	chmod +x $file
done
# openSUSE
%if 0%{?suse_version}
%suse_update_desktop_file -i %{buildroot}/%{_datadir}/applications/nagstamon.desktop
%endif
# Fedora
%if 0%{?fedora_version}
desktop-file-install --dir %{buildroot}/%{_datadir}/applications \
    --vendor OBS \
    --delete-original \
    %{buildroot}/%{_datadir}/applications/nagstamon.desktop
%endif
# Mandriva
%if 0%{?mandriva_version}
desktop-file-install --vendor="OBS" \
  --dir=%{buildroot}%{_datadir}/applications \
  %{buildroot}/%{_datadir}/applications/nagstamon.desktop

%post
%{update_menus}

%postun
%{clean_menus}
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc ChangeLog COPYRIGHT LICENSE
%{_datadir}/pixmaps/nagstamon*
%{_datadir}/applications/*nagstamon.desktop
%{python3_sitelib}/Nagstamon/
%{_bindir}/nagstamon
%{_mandir}/man1/nagstamon.1*
%{python3_sitelib}/%{name}*.egg-info

%changelog
* Thu Oct 20 2016 lars@linux-schulserver.de
- update to 2.0.1:
  Despite months of testing there were some bugs in the latest stable release,
  which hopefully are gone now. This release tries to fix the following bugs:
  + Major Centreon bug making it useless
  + Wrong Icinga version check
  + Thruk login problem
  + EWMH initialization trouble
  + Systrayicon left mouse click brought context menu
  + DBus crashes
* Wed Oct 19 2016 lars@linux-schulserver.de
- remove dependency on libqt5-qtmultimedia and build require
  libqt5-qtmultimedia-devel instead
* Fri Sep  2 2016 lars@linux-schulserver.de
- update to 2.0:
  After a major overhaul Nagstamon is finally available in its 2.0
  incarnation. Being formerly formed of Python 2 and GTK 2 it now comes
  freshly reshaped, made of Python 3 and Qt 5.
  This technology shift caused the longer absence of any other stable
  release, but was absolutely necessary to make sure there will be
  future releases too.
  These are some new features and fixes:
  + Based on Qt 5 it now comes with a better integrated look-and-feel
  + Partly simplified design
  + Less clutter in setting dialogs
  + Uses QT 5 multimedia which means native sound on Linux and MacOS
  + Uses only SVG graphics – allows changing colors even in systray icon
  + Customizable font and font size
  + Adjust to dark or light desktop theme
  + Action allowing to copy host/service information to clipboard
  + Added ‘Archive Event’ action for Check_MK monitors
  + Additionally supports IcingaWeb2
  + Updated Opsview and Centreon to support latest monitor server versions
  + Experimental support for Livestatus and Zenoss
  + No or less memory leaks, especially in Windows
  + Make sure only one instance per config is running
  + Millions of fixes
- adapted spec file to build again for Fedora and build with the latest
  changes of the 2.0 version (QT instead of GTK)
- builds only with Python 3 - so removing case decisions for old
  distributions that are no longer supported
* Sat Dec 27 2014 lars@linux-schulserver.de
- update to 1.0.1:
  + added option to disable system keyring storage to prevent crashes
  + reverted default sorting order to "Descending"
  + fixed too narrow fullscreen display
* Mon Jul 28 2014 lars@linux-schulserver.de
- update to 1.0:
  + added custom event notification with custom commands
  + added highlighting of new events
  + added storage of passwords in OS keyring
  + added optional tooltip for full status information
  + added support for applying custom actions to specific monitor only
  + added copy buttons for servers and actions dialogs
  + added stopping notification if event already vanished
  + added support for Op5Monitor 6.3 instead of Ninja
  + added experimental Zabbix support
  + added automatic refreshing after acknowledging
  + added permanent hamburger menu
  + unified layout of dialogs
  + various Check_MK improvements
  + fixed old regression not-staying-on-top-bug
  + fixed Check_MK-Recheck-DOS-bug
  + fixed pop window size calculation on multiple screens
  + fixed following popup window on multiple screens
  + fixed hiding dialogs in MacOSX
  + fixed ugly statusbar font in MacOSX
  + fixed use of changed colors
  + fixed non-ascending default sort order
  + fixed Opsview downtime dialog
  + fixed sometimes not working context menu
  + fixed some GUI glitches
  + fixed password saving bug
  + fixed Centreon language inconsistencies
  + fixed regression Umlaut bug
* Wed Sep 11 2013 lars@linux-schulserver.de
- update to 0.9.11:
  + added libnotify desktop notification support
  + added Centreon criticality support
  + fixed broken authentication dialog
  + fixed wrong OK state for Nagios and Icinga
  + fixed Correct-Statusbar-Position-O-Matic
  + fixed some Thruk issues
  + fixed popup resizing artefact
  + fixed some server edit dialog bugs
  + fixed missing auth field in Icinga when credentials are wrong
  + fixed quoting URLs for browser actions
* Sat Jul 13 2013 lars@linux-schulserver.de
- update to 0.9.10:
  + added fullscreen option
  + added Thruk support
  + added Check_MK cookie-based auth
  + added new Centreon autologin option
  + added configurable default sort order
  + added filter for hosts in hard/soft state for Nagios, Icinga,
    Opsview and Centreon
  + added $STATUS-INFO$ variable for custom actions
  + added audio alarms also in fullscreen mode
  + improved update interval set in seconds instead minutes
  + improved Icinga JSON support
  + improved Centreon 2.4 xml/broker support
  + improved Nagios 3.4 pagination support
  + improved nicer GTK theme Murrine on MacOSX
  + fixed security bug
  + fixed some memory leaks
  + fixed superfluous passive icon for Check_MK
  + fixed blocking of shutdown/reboot on MacOSX
  + fixed saving converted pre 0.9.9 config immediately
  + fixed statusbar position when offscreen
  + fixed some GUI issues
  + fixed update detection
- this version fixes a security bug in the automatic update check
  (mentioned in CVE-2013-4114 and bnc #829217)
* Wed Apr 17 2013 lars@linux-schulserver.de
- fix build on CentOS > 5
* Fri Apr 13 2012 lars@linux-schulserver.de
- update to 0.9.9 (final):
  + fixed popwin misplacement
  + many fixes for the Windows port
* Tue Mar 13 2012 lars@linux-schulserver.de
- update to 0.9.9 Release Candidate 17 (0.9.9.17):
  + added custom actions in context menu (see documentation)
  + added reauthentication in case of authenticaton problems
  + added filter for flapping hosts and services
  + added history button for monitors
  + added shortcut to filter settings in popup window
  + improved keyboard usage in acknowledge/downtime/submit dialogs
  + changed configuration file to configuration directory
    (default: ~/.nagstamon)
  + fixed bug in Icinga acknowledgement
  + fixed bug in Check_MK Multisite sorting
  + fixed some Check_MK Multisite UTF trouble
* Sun Oct 30 2011 lars@linux-schulserver.de
- cleanup specfile as suggested in rq 89595
* Fri Oct 28 2011 cfarrell@suse.com
- license update: GPL-2.0
  SPDX format (http://www.spdx.org/licenses)
* Thu Oct 27 2011 lars@linux-schulserver.de
- update to 0.9.8:
  + added customizable acknowledge/downtime/submit-result defaults
  + added regexp filter for status information column
  + added option to connect to hosts via its monitor hostname
    without HTTP overhead
  + added ability to keep status detail popup open despite
    hovering away
  + added option to change offset between popup window and systray
    icon to avoid partly hidden popup
  + fixed some popup artefacts
  + fixed various bugs with acknowledgement flags
    (persistent/sticky/notification), now they are actually working
- build as noarch package on openSUSE > 11.2
- recommend gnome-terminal, rdesktop, tightvnc on openSUSE (the
  default binaries used by nagstamon)
- require python-egg on openSUSE (needed for module egg.trayicon)
  and python-setuptools
* Wed Jul  6 2011 lars@linux-schulserver.de
- require python-setuptools on Fedora and fix the desktop file
* Sat Jun 11 2011 lars@linux-schulserver.de
- update to 0.9.7.1:
  + fixed sf.net bug 3309166 which broke Centreon support
* Mon May 30 2011 lars@linux-schulserver.de
- update to 0.9.7:
  + on some servers now context menu allows submitting check results
    for hosts and services
  + added filter for services on acknowledged hosts
  + added icons for "passiveonly" and "flapping" hosts and services
  + fix for uneditable text entry fields in settings dialog -
    sf.net bug 3300873
  + fix for not working filter "services on hosts in maintenance" -
    sf.net bug 3299790
  + fix for soft state detection in Centreon - sf.net bug 3303861
  + fix for not filtered services which should have been filtered -
    sf.net bug 3308008
- specfile cleanup using spec-cleaner
- use svg image for desktop icon
* Tue May 24 2011 lars@linux-schulserver.de
- enable build for Fedora and Mandriva
- fix desktop icon
* Mon May 23 2011 lars@linux-schulserver.de
- initial version 0.9.6.1
